@@ -1,15 +1,11 @@
 #!/usr/bin/env bash
-
-# netdata
-# real-time performance and health monitoring, done right!
-# (C) 2023 Netdata Inc.
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
 # This script is a helper to allow netdata collect tc data.
 # tc output parsing has been implemented in C, inside netdata
 # This script allows setting names to dimensions.
 
-export PATH="${PATH}:/sbin:/usr/sbin:/usr/local/sbin:/usr/sbin"
+export PATH="${PATH}:/sbin:/usr/sbin:/usr/local/sbin:/usr/bin"
 export LC_ALL=C
 
 cmd_line="'${0}' $(printf "'%s' " "${@}")"
@@ -154,7 +150,7 @@ if [ ! -d "${fireqos_run_dir}" ]; then
 			warning "Although FireQOS is installed on this system as '${fireqos}', I cannot find/read its installation configuration at '${fireqos_exec_dir}/install.config'."
 		fi
 	else
-		warning "FireQOS is not installed on this system. Use FireQOS to apply traffic QoS and expose the class names to netdata. Check https://github.com/netdata/netdata/tree/master/collectors/tc.plugin#tcplugin"
+		warning "FireQOS is not installed on this system. Use FireQOS to apply traffic QoS and expose the class names to netdata. Check https://github.com/netdata/netdata/tree/master/src/collectors/tc.plugin#tcplugin"
 	fi
 fi
 
